@@ -3,7 +3,7 @@ package App::paperback;
 use v5.10;
 use strict;
 # use warnings;
-our $VERSION = "1.24";
+our $VERSION = "1.25";
 
 my ($GinFile, $GpageObjNr, $GrootNr, $Gpos, $GobjNr, $Gstream, $GoWid, $GoHei);
 my (@Gkids, @Gcounts, @GmediaBox, @Gobject, @Gparents, @Gto_be_created);
@@ -140,17 +140,12 @@ For further details, please try 'perldoc paperback'.
 ${sayVersion}
 END_MESSAGE
 
-  die "[!] ${sayUsage}\n"
-    if ! defined $input;
+  die "[!] ${sayUsage}\n" if ! defined $input;
   do {print STDERR "${sayHelp}" and exit}
     if $input =~ "^-h\$" or $input =~ "^--help\$";
   do {print STDERR "${sayVersion}\n" and exit}
     if $input =~ "^-v\$" or $input =~ "^--version\$";
-  die "[!] File '${input}' can't be found or read.\n"
-    unless -r $input;
   ($inpPgNum, $inpPgSize) = openInputFile($input);
-  die "[!] File '${input}' is not a valid v1.4 PDF file.\n"
-    if $inpPgNum == 0;
 
   my ($pgPerOutputPage, @x, @y);
   for ($inpPgSize) {
@@ -456,7 +451,7 @@ sub getRootAndMapGobjects {
 
   sysseek $IN_FILE, -150, 2;
   sysread $IN_FILE, $buf, 200;
-  die "[!] File ${GinFile} is encrypted, cannot be used. Aborting.\n"
+  die "[!] File '${GinFile}'' is encrypted, cannot be used. Aborting.\n"
     if $buf =~ m'Encrypt';
 
   if ($buf =~ m'/Prev\s+\d') { # "Versioned" PDF file (several xref sections)
@@ -477,7 +472,7 @@ sub getRootAndMapGobjects {
   }
 
   # stat[7] = filesize
-  die "[!] Invalid XREF. Aborting.\n" if $xref > (stat($GinFile))[7];
+  die "[!] Invalid XREF. Aborting.\n" if $xref > getInputFileWeight();
   populateGobjects($xref);
   $tempRoot = getRootFromTraditionalXrefSection();
   return 0 unless $tempRoot; # No Root object in ${GinFile}, aborting
@@ -514,7 +509,7 @@ sub populateGobjects {
 
   if ($readBytes =~ /^(xref$cr)/) {              # Input PDF is v1.4 or lower
     mapGobjectsFromTraditionalXref($xrefPos + length($1));
-  } elsif ($readBytes =~ m'^\d+\s+\d+\s+obj'i) { # Input PDF is v1.5 or higher
+  } elsif ($readBytes =~ m'^\d+\s+\d+\s+obj') { # Input PDF is v1.5 or higher
     die "[!] File '${GinFile}' uses xref streams (not a v1.4 PDF file).\n";
   } else {
     die "[!] File '${GinFile}' has a malformed xref table.\n";
@@ -533,7 +528,7 @@ sub getRootFromTraditionalXrefSection {
   while ($readBytes) {
     sysread $IN_FILE, $readBytes, 200;
     $buf .= $readBytes;
-    return $1 if $buf =~ m'\/Root\s+(\d+)\s+\d+\s+R's;
+    return $1 if $buf =~ m'\/Root\s+(\d+)\s+\d+\s+R';
   }
   return;
 }
@@ -570,7 +565,7 @@ sub writePageObjectsToOutputFile {
       $out_line .= substr( $objectContent, $strPos );
     } else {
       $objectContent = substr( $objectContent, length($1) )
-        if $objectContent =~ m'^(\d+ \d+ obj)\b's;
+        if $objectContent =~ m'^(\d+ \d+ obj)\b';
       update_references_and_populate_to_be_created($objectContent);
       $out_line = "${new_one} 0 obj ${objectContent}";
     }
@@ -583,18 +578,10 @@ sub writePageObjectsToOutputFile {
 
 
 ##########################################################
-sub getInputPageDimensions {
+sub setOutputPageDimensionAndSchema {
 ##########################################################
-  # Find root:
-  my $objectContent = getContentOfObjectNr($GrootNr);
-
-  # Find pages:
-  return "unknown" unless $objectContent =~ m'/Pages\s+(\d+)\s+\d+\s+R's;
-  $objectContent = getContentOfObjectNr($1);
-  $objectContent = xformObjForThisPage($objectContent, 1)
-    unless $objectContent =~ m'MediaBox's;
-  (undef, undef) = parseAsResourcesAndContentRef( $objectContent );
-  return "unknown" if ! defined $GmediaBox[2] or ! defined $GmediaBox[3];
+  die "[!] File '${GinFile}' is not a valid v1.4 PDF.\n" 
+    unless getPageSizeAndSetMediabox();
 
   my $surface = $GmediaBox[2]*$GmediaBox[3];
   my $measuresInMm = int($GmediaBox[2] / 72 * 25.4) . " x "
@@ -640,7 +627,7 @@ sub getPage {
 
   # Find pages:
   die "[!] Didn't find Pages section in '${GinFile}'. Aborting.\n"
-    unless $objectContent =~ m'/Pages\s+(\d+)\s+\d+\s+R's;
+    unless $objectContent =~ m'/Pages\s+(\d+)\s+\d+\s+R';
   $objectContent = getContentOfObjectNr($1);
   $objectContent = xformObjForThisPage($objectContent, $pagenumber);
   ($formRes, $formCont) = parseAsResourcesAndContentRef($objectContent);
@@ -676,24 +663,24 @@ sub xformObjForThisPage {
   my ($objectContent, $pagenumber) = ($_[0], $_[1]);
   my ($vector, @pageObj, @pageObjBackup, $pageAccumulator);
 
-  return 0 unless $objectContent =~ m'/Kids\s*\[([^\]]+)'s;
+  return 0 unless $objectContent =~ m'/Kids\s*\[([^\]]+)';
   $vector = $1;
 
   $pageAccumulator = 0;
 
-  push @pageObj, $1 while $vector =~ m'(\d+)\s+\d+\s+R'gs;
+  push @pageObj, $1 while $vector =~ m'(\d+)\s+\d+\s+R'g;
   while ( $pageAccumulator < $pagenumber ) {
     @pageObjBackup = @pageObj;
     undef @pageObj;
     last if ! @pageObjBackup; # $pagenumber is > than number of pages in PDF
     for (@pageObjBackup) {
       $objectContent = getContentOfObjectNr($_);
-      if ( $objectContent =~ m'/Count\s+(\d+)'s ) {
+      if ( $objectContent =~ m'/Count\s+(\d+)' ) {
         if ( ( $pageAccumulator + $1 ) < $pagenumber ) {
           $pageAccumulator += $1;
         } else {
-          $vector = $1 if $objectContent =~ m'/Kids\s*\[([^\]]+)'s ;
-          push @pageObj, $1 while $vector =~ m'(\d+)\s+\d+\s+R'gs;
+          $vector = $1 if $objectContent =~ m'/Kids\s*\[([^\]]+)' ;
+          push @pageObj, $1 while $vector =~ m'(\d+)\s+\d+\s+R'g;
           last;
         }
       } else {
@@ -706,33 +693,48 @@ sub xformObjForThisPage {
 }
 
 
+##########################################################
+sub getPageSizeAndSetMediabox {
+##########################################################
+  # Find root:
+  my $objectContent = getContentOfObjectNr($GrootNr);
+
+  # Find pages:
+  return "unknown" unless $objectContent =~ m'/Pages\s+(\d+)\s+\d+\s+R';
+  $objectContent = getContentOfObjectNr($1);
+  $objectContent = xformObjForThisPage($objectContent, 1)
+    unless $objectContent =~ m'MediaBox';
+
+  # Assume all input PDF pages have the same dimensions as first MediaBox found:
+  if (! @GmediaBox) {
+    for ($objectContent) {
+      if (m'MediaBox\s*\[\s*([\S]+)\s+([\S]+)\s+([\S]+)\s+([\S]+)\s*\]') {
+        @GmediaBox = ($1, $2, $3, $4);
+      } elsif (m'MediaBox\s*(\d+)\s+\d+\s+R\b') { # Size to be found in reference
+        my $ref = getContentOfObjectNr($1);
+        @GmediaBox = ($1, $2, $3, $4)
+          if ($ref =~ m'\[\s*([\S]+)\s+([\S]+)\s+([\S]+)\s+([\S]+)\s*\]');
+      } else {
+        return 0;
+      }
+    }
+  }
+  return 1;
+}
+
+
 ##########################################################
 sub parseAsResourcesAndContentRef {
 ##########################################################
   my $objContent = $_[0];
   my ($resources, $formCont);
 
-  # Assume all input PDF pages have the same dimensions as first MediaBox found:
-  if (! @GmediaBox) {
-    for ($objContent) {
-      if (m'MediaBox\s*\[\s*([\S]+)\s+([\S]+)\s+([\S]+)\s+([\S]+)\s*\]'s) {
-        @GmediaBox = ($1, $2, $3, $4);
-      } elsif (m'MediaBox\s*(\d+)\s+\d+\s+R\b's) { # Size to be found in reference
-        my $ref = getContentOfObjectNr($1);
-        @GmediaBox = ($1, $2, $3, $4)
-          if ($ref =~ m'\[\s*([\S]+)\s+([\S]+)\s+([\S]+)\s+([\S]+)\s*\]'s);
-      }
-    }
-  }
-
-  if ( $objContent =~ m'/Contents\s+(\d+)'s ) {
+  if ( $objContent =~ m'/Contents\s+(\d+)' ) {
     $formCont = $1;
-  } elsif ( $objContent =~ m'/Contents\s*\[\s*(\d+)\s+\d+\s+R\s*\]'s ) {
+  } elsif ( $objContent =~ m'/Contents\s*\[\s*(\d+)\s+\d+\s+R\s*\]' ) {
     $formCont = $1;
   }
-
   $resources = getResourcesFromObj($objContent);
-
   return ($resources, $formCont);
 }
 
@@ -743,18 +745,18 @@ sub getResourcesFromObj {
   my $objContent = $_[0];
   my $resources;
 
-  if ( $objContent =~ m'^(.+/Resources)'s ) {
-    return $1 if $objContent =~ m'Resources\s+(\d+\s+\d+\s+R)'s; # Reference (95%)
+  return $1 if $objContent =~ m'Resources\s+(\d+\s+\d+\s+R)'; # Reference (95%)
+  if ( $objContent =~ m'^.+/Resources's ) {
     # The resources are a dictionary. The whole is copied (morfologia.pdf):
     my $k;
     ( undef, $objContent ) = split /\/Resources/, $objContent;
-    $objContent =~ s/<</#<</gs;
-    $objContent =~ s/>>/>>#/gs;
+    $objContent =~ s/<</#<</g;
+    $objContent =~ s/>>/>>#/g;
     for ( split /#/, $objContent ) {
-      if ( m'\S's ) {
+      if ( m'\S' ) {
         $resources .= $_;
-        ++$k if m'<<'s;
-        --$k if m'>>'s;
+        ++$k if m'<<';
+        --$k if m'>>';
         last if $k == 0;
       }
     }
@@ -771,9 +773,9 @@ sub getInputPageCount {
   my $objectContent;
 
   return 0 unless eval { $objectContent = getContentOfObjectNr($GrootNr); 1; };
-  if ( $objectContent =~ m'/Pages\s+(\d+)\s+\d+\s+R's ) {
+  if ( $objectContent =~ m'/Pages\s+(\d+)\s+\d+\s+R' ) {
     $objectContent = getContentOfObjectNr($1);
-    $maxPages = $1 if $objectContent =~ m'/Count\s+(\d+)'s;
+    $maxPages = $1 if $objectContent =~ m'/Count\s+(\d+)';
   }
   return $maxPages;
 }
@@ -784,28 +786,38 @@ sub openInputFile {
 ##########################################################
   $GinFile = $_[0];
   my ( $objectContent, $inputPageSize, $inputPageCount, $c );
+  die "[!] File '${GinFile}' is empty.\n" if ! getInputFileWeight();
 
-  open( $IN_FILE, q{<}, $GinFile )
-    or die "[!] Couldn't open '${GinFile}'.\n";
+  open($IN_FILE, q{<}, $GinFile) or die "[!] Couldn't open '${GinFile}'.\n";
   binmode $IN_FILE;
 
   sysread $IN_FILE, $c, 5;
-  return 0 if $c ne "%PDF-";
+  die "[!] File '${GinFile}' is not a valid v1.4 PDF file.\n" if $c ne "%PDF-";
 
   # Find root
   $GrootNr = getRootAndMapGobjects();
-  return 0 unless $GrootNr > 0;
+  die "[!] File '${GinFile}' is not a valid v1.4 PDF file.\n" unless $GrootNr > 0;
 
-  $inputPageSize = getInputPageDimensions();
+  $inputPageSize = setOutputPageDimensionAndSchema();
   $inputPageCount = getInputPageCount();
+
   return ($inputPageCount, $inputPageSize);
 }
 
 
+##########################################################
+sub getInputFileWeight {
+##########################################################
+  state $known;
+  $known = (stat($GinFile))[7] if ! $known;
+  return $known;
+}
+
+
 ##########################################################
 sub addSizeToGObjects {
 ##########################################################
-  my $size = (stat($GinFile))[7];  # stat[7] = filesize
+  my $size = getInputFileWeight();
   # Objects are sorted numerically (<=>) and in reverse order ($b $a)
   # according to their offset in the file: last first
   my @offset = sort { $GObjects{$b} <=> $GObjects{$a} } keys %GObjects;
@@ -842,7 +854,7 @@ sub extractXrefSection {
   my $readBytes = ""; my ($qty, $idx, $c);
 
   sysread $IN_FILE, $c, 1;
-  sysread $IN_FILE, $c, 1 while $c =~ m'\s's;
+  sysread $IN_FILE, $c, 1 while $c =~ m'\s';
   while ( $c =~ /[\d ]/ ) {
     $readBytes .= $c;
     sysread $IN_FILE, $c, 1;
@@ -891,7 +903,7 @@ App::paperback - Copy and transform pages from a PDF into a new PDF
 
  #!/usr/bin/env perl
  use strict;
- use App::paperback qw(openInputFile);
+ use App::paperback;
  my $inputFile              = "some-A6-pages.pdf";
  my $outputFile             = "new-A4-pages.pdf";
  my $desiredPage            = 1;
